isDeviceSupportedByAuth method

Future<bool> isDeviceSupportedByAuth()

Returns true if device is capable of checking biometrics or is able to fail over to device credentials.

Implementation

Future<bool> isDeviceSupportedByAuth() async {
  return await _auth.isDeviceSupported();
}