CredentialsManager class
A library to easy manage your app credentials
Constructors
- CredentialsManager({required String storageKey, })
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageKey → String
-
The identifier of the secure storage.
final
Methods
-
canCheckBiometrics(
) → Future< bool> - Returns true if device is capable of checking biometrics.
-
getSavedCredentials(
) → Future< List< CredentialModel> > - Get all saved credentials
-
isDeviceSupportedByAuth(
) → Future< bool> - Returns true if device is capable of checking biometrics or is able to fail over to device credentials.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeAllCredentials(
) → Future< void> - Remove all credentials from storage.
-
removeCredential(
CredentialModel credentialModel) → Future< void> - Remove a single credential from storage.
-
requestAuth(
{String authReasonMessage = 'Please authenticate to continue.', bool biometricOnly = false, bool cannotAuthResult = false}) → Future< bool> - Authenticates the user with biometrics available on the device while also allowing the user to use device authentication - pin, pattern, passcode.
-
saveCredential(
CredentialModel credentialModel) → Future< void> - Save credential in a secure local storage.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited